@@ -16,6 +16,7 @@ import ast as __ast
 import json as __json
 import sys as __sys
 import readline as __readline
+from time import sleep as __sleep
 
 __readline.parse_and_bind('tab: complete')
 
@@ -89,6 +90,7 @@ def getModulesNames():
     modules_names = []
     for tools in __modules_loaded__:
         modules_names.append(tools.split('.')[-1])
+    modules_names.sort()
     return modules_names
 
 def getModulesFromCategory(category):
@@ -117,6 +119,11 @@ def getModule(moduleName):
         eval(module)
     """
     #Logger.printMessage('Initiation of {moduleName}'.format(moduleName=moduleName), debug_module=True)
+
+    # While the mods are loading with workers, wait por it
+    while any( [ work.startswith('import-module-') for work in getWorkers() ] ):
+        __sleep(0.1)
+
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
@@ -575,8 +582,6 @@ def __importModules__():
                         worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
                     else:
                         __importModule__(modules=modu, category=submod, moduleName=module_name)
-                        if 'urlshortener' in module_name:
-                            print(__modules_loaded__)
                 except Exception as e:
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
