@@ -13,7 +13,7 @@ output_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), 'output'))
 class StartModule():
 
 	def __init__(self):
-		self._main_gui_func_ = ''
+		self._main_gui_func_ = 'createShortcut'
 		self._funcArgFromFunc_ = {
 			'createShortcut' : {
 				'domainShortener' : {
